# Copyright (C) 2007-2008 www.stani.be
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see http://www.gnu.org/licenses/


__all__ = ['CONTEXT', 'check_font_cache', 'check_user_paths']


import os
import shutil
import subprocess
import sys

from lib import system
from lib import openImage

from version import VERSION

if __name__ == '__main__':
    sys.path.insert(0, '..')

from lib.context import get_context, join, join_create, BIN, ContextError, \
    PATHS


CONTEXT = get_context(app_name='phatch', base_source='phatch',
    sys_prefix=sys.prefix)

# modules
IMPORT_OK = '<installed>'
IMPORT_ERROR = '<not installed>'
try:
    if CONTEXT['distribute'] == 'frozen':
        from lib import pilPlugins
    import Image
    CONTEXT['version_pil'] = Image.VERSION
except ImportError:
    CONTEXT['version_pil'] = IMPORT_ERROR
try:
    import pyexiv2
    CONTEXT['version_pyexiv2'] = IMPORT_OK
except ImportError:
    CONTEXT['version_pyexiv2'] = IMPORT_ERROR
CONTEXT['version_app'] = VERSION

# extension
CONTEXT['app_extension'] = '.%(app_name)s' % CONTEXT
if CONTEXT['context'] == ('windows', 'frozen'):
    CONTEXT['py_extension'] = '*.pyc'
else:
    CONTEXT['py_extension'] = '*.py'

# application paths

# actions paths
if CONTEXT['context'] == ('apple', 'frozen'):
    CONTEXT['app_actions_path'] = join(CONTEXT['app_data_path'], 'actions')
else:
    CONTEXT['app_actions_path'] = join(CONTEXT['app_source_path'], 'actions')

# data paths
    # other data pats
CONTEXT['app_actionlists_path'] = join(CONTEXT['app_data_path'], 'actionlists')
CONTEXT['app_blender_path'] = join(CONTEXT['app_data_path'], 'blender')
CONTEXT['app_fonts_path'] = join(CONTEXT['app_data_path'], 'fonts')
CONTEXT['app_fonts_cache_path'] = os.path.join(CONTEXT['app_data_path'],
    'fonts.cache')

# images paths (data/images)
CONTEXT['app_images_path'] = join(CONTEXT['app_data_path'], 'images')
CONTEXT['app_highlights_path'] = join(CONTEXT['app_images_path'], 'highlights')
CONTEXT['app_masks_path'] = join(CONTEXT['app_images_path'], 'masks')
CONTEXT['app_watermarks_path'] = join(CONTEXT['app_images_path'], 'watermarks')
# TODO Nadia check phatch.ico on source and py2exe (check this with setup.py!)
# app_icons_path is different for each context, so should not be used later
if CONTEXT['distribute'] == 'frozen':
    app_icons_path = join(CONTEXT['app_images_path'], 'icons')
    CONTEXT['phatch_48x48.png'] = join(app_icons_path, 'phatch.png')
    CONTEXT['phatch.ico'] = join(app_icons_path, 'phatch.ico')
    CONTEXT['phatch-inspector.ico'] = \
        join(app_icons_path, 'phatch-inspector.ico')
    bin_root = os.path.join(CONTEXT['app_source_path'], 'bin')
    CONTEXT['app_bin_paths'] = [
        bin_root,
        os.path.join(bin_root, 'blender'),
        os.path.join(bin_root, 'imagemagick'),
        CONTEXT['app_source_path'],
    ]
elif CONTEXT['distribute'] == 'source':
    app_icons_path = join(CONTEXT['app_data_path'], '..', 'setup', 'images',
        'icons')
    CONTEXT['phatch_48x48.png'] = join(app_icons_path, '48x48', 'phatch.png')
    CONTEXT['phatch.ico'] = join(app_icons_path, '256x256', 'phatch.ico')
    CONTEXT['phatch-inspector.ico'] = \
        join(app_icons_path, '256x256', 'phatch.ico')
    bin_root = os.path.join(CONTEXT['app_source_path'], '..', '..', 'bin')
    CONTEXT['app_bin_paths'] = [
        bin_root,
        os.path.join(bin_root, 'blender'),
        os.path.join(bin_root, 'imagemagick'),
    ]
else:
    CONTEXT['phatch_48x48.png'] = join(CONTEXT['app_images_path'], 'icons',
        'phatch.png')
    CONTEXT['app_bin_paths'] = []
    #CONTEXT['phatch.ico'] should throw a KeyError on Linux

# previews paths (data/gui)
CONTEXT['app_gui_path'] = join(CONTEXT['app_data_path'], 'gui')
CONTEXT['app_preview_path'] = join(CONTEXT['app_gui_path'], 'preview')
CONTEXT['app_preview_actionlists_path'] = join(CONTEXT['app_preview_path'],
    'actionlists')
CONTEXT['app_preview_blender_path'] = join(CONTEXT['app_preview_path'],
    'blender')
CONTEXT['app_preview_perspective_path'] = join(CONTEXT['app_preview_path'],
    'perspective')

# doc paths
found = False
for sub in ([], ['html'], ['build', 'html']):
    CONTEXT['app_doc_dev_path'] = os.path.join(
        CONTEXT['app_doc_path'],
        *(sub + ['index.html'])
    )
    if os.path.exists(CONTEXT['app_doc_dev_path']):
        found = True
        break
if not found:
    del CONTEXT['app_doc_dev_path']
    if not ((CONTEXT['linux'] and BIN) or PATHS):
        # Linux might package phatch-doc seperately
        raise ContextError('Developer documentation can not be found in "%s".'
            % CONTEXT['app_doc_path'])
del found

# user paths

# user cache paths
CONTEXT['user_fonts_cache_path'] = os.path.join(CONTEXT['user_cache_path'],
    'fonts.cache')
CONTEXT['user_log_path'] = os.path.join(CONTEXT['user_cache_path'], 'log')
CONTEXT['user_preview_path'] = join_create(CONTEXT['user_cache_path'],
    'preview')

# user config paths
CONTEXT['user_settings_path'] = os.path.join(CONTEXT['user_config_path'],
    'settings.py')

# user data paths (will be created if they don't exist)
CONTEXT['user_actions_path'] = join_create(CONTEXT['user_data_path'],
    'actions')
CONTEXT['user_actionlists_path'] = join_create(CONTEXT['user_data_path'],
    'actionlists')
CONTEXT['user_bin_paths'] = [join_create(CONTEXT['user_data_path'], 'bin')]
CONTEXT['user_fonts_path'] = join_create(CONTEXT['user_data_path'], 'fonts')
CONTEXT['user_geek_path'] = os.path.join(CONTEXT['user_data_path'], 'geek.txt')

# user images paths ((will be created if they don't exist)
CONTEXT['user_highlights_path'] = join_create(CONTEXT['user_data_path'],
    'highlights')
CONTEXT['user_masks_path'] = join_create(CONTEXT['user_data_path'], 'masks')
CONTEXT['user_watermarks_path'] = join_create(CONTEXT['user_data_path'],
    'watermarks')

# register bin paths
system.set_bin_paths(CONTEXT['user_bin_paths'] + CONTEXT['app_bin_paths'])
openImage.register()


def check_font_cache(force=False):
    if force or not(
            os.path.exists(CONTEXT['user_fonts_cache_path']) or \
            os.path.exists(CONTEXT['app_fonts_cache_path'])
        ):
        # TODO Nadia: how would this work for py2app and py2exe
        subprocess.Popen([sys.executable,
            os.path.abspath(sys.argv[0]), '--fonts'])


def check_user_paths(force_font_cache=False):
    if not os.path.exists(CONTEXT['user_geek_path']):
        shutil.copyfile(
            os.path.join(CONTEXT['app_data_path'], 'geek.txt'),
            CONTEXT['user_geek_path']
        )
    check_font_cache(force_font_cache)


if __name__ == '__main__':
    import pprint
    pprint.pprint(CONTEXT)
