# Copyright (C) 2007-2010 www.stani.be
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see http://www.gnu.org/licenses/


__all__ = ['load_locale']


import gettext
import glob
import locale
import os


def load_locale(app, path, canonical='default', use_unicode=True):
    locale.setlocale(locale.LC_ALL, '')
    #get default canonical if necessary
    if canonical == 'default':
        canonical = locale.getdefaultlocale(envvars=('LC_ALL', 'LANG'))[0]
        if canonical is None:
            #for mac
            canonical = 'en'
    #canonical = 'zh' #to test unicode languages
    #expand with similar translations
    base = canonical.split('_')[0]  # eg pt_BR -> pt
    base_path = os.path.join(path, base)
    languages = [base_path] + \
        [os.path.basename(x) for x in glob.glob(base_path + '_*')]
    #ensure canonical is the first element (base the second)
    if canonical in languages:
        languages.remove(canonical)
    languages.insert(0, canonical)
    #install
    i18n = gettext.translation(app, path, languages=languages, fallback=1)
    i18n.install(unicode=use_unicode)
