# Copyright (C) 2010 www.stani.be
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see http://www.gnu.org/licenses/

# http://www.freedesktop.org/wiki/Specifications/desktop-bookmark-spec
# http://library.gnome.org/devel/pygtk/stable/class-gtkrecentmanager.html

import sys


def _init_add():

    def ignore(filename, recent_data=None):
        return False

    # windows
    if sys.platform.startswith('win'):
        try:
            from win32ui import AddToRecentFileList

            def add(filename, recent_data=None):
                AddToRecentFileList(filename)
                return True

        except ImportError:
            return ignore

    # linux
    elif not sys.platform.startswith('darwin'):

        import urllib

        try:
            import gtk
            gtk_manager = gtk.recent_manager_get_default()
        except:
            return ignore

        def add(filename, recent_data=None):
            uri = 'file://%s' % urllib.quote(filename)
            if recent_data:
                gtk_manager.add_full(uri, recent_data)
            else:
                gtk_manager.add_item(uri)
            return True

    return add

add = _init_add()
